@@ -23,7 +23,7 @@
  project version    : Please see "main.cpp" for project version
 
  developer          : luckyb 
- last modified      : 07 Jun 2011
+ last modified      : 22 May 2016
 ===============================================================================================================================
 ===============================================================================================================================
 */
@@ -31,6 +31,12 @@
 
 #include "calcDiffThread.h"
 
+#include <QStack>
+#include <QTextStream>
+
+#include "global.h"
+#include "operationClass.h"
+
 // class CalcDiffThread Constructor=================================================================================================
 CalcDiffThread::CalcDiffThread(QObject *parent) : QThread(parent)
 {
@@ -44,8 +50,8 @@ CalcDiffThread::CalcDiffThread(QObject *parent) : QThread(parent)
     source 	= "";
     CurrentSnapshotNo 	= 0;
     currentSnaps 	= 0;
-    syncTYPE 	= FALSE;
-    abortNOW	= FALSE;
+    syncTYPE 	= false;
+    abortNOW	= false;
 }
 
 // class CalcDiffThread Destructor=================================================================================================
@@ -58,7 +64,7 @@ CalcDiffThread::~CalcDiffThread ()
 void CalcDiffThread::run ()
 {
     returnString = "";
-    emit updateViewer(tr("Scanning destination") + "\n\n..." + tr("Please wait"), FALSE);
+    emit updateViewer(tr("Scanning destination") + "\n\n..." + tr("Please wait"), false);
     QFileInfoList returnDirContents = readRecursive(dirToReadString);		//this is the destination as a Qfileinfo list
     
     int countDirEntries=0, countReturnEntries=0;
@@ -105,18 +111,18 @@ void CalcDiffThread::run ()
         destFile.remove(dest, Qt::CaseSensitive);
         
         countDirEntries = 0;
-        bool removed = FALSE;
+        bool removed = false;
         while (countDirEntries < removedFiles.size())
         {
             if ( (destFile == removedFiles.at(countDirEntries)) || ((destFile+SLASH) == removedFiles.at(countDirEntries)) )
             {
-                removed = TRUE;
+                removed = true;
                 returnDirContents.removeAt(countReturnEntries);
             }
             countDirEntries++;
         }
         if (removed)
-            removed = FALSE;
+            removed = false;
         else
             countReturnEntries++;
     }
@@ -132,7 +138,7 @@ void CalcDiffThread::run ()
         QDir currentsnapdir(SnapshotDirectoryToRead);
         if ( (currentsnapdir.exists()) && (!syncTYPE) )
         {
-            emit updateViewer(tr("Scanning snapshot") + " " + SnapshotDirectoryStringToRead + "\n\n..." + tr("Please wait"), FALSE);
+            emit updateViewer(tr("Scanning snapshot") + " " + SnapshotDirectoryStringToRead + "\n\n..." + tr("Please wait"), false);
             QFileInfoList currentsnapdirContents = readRecursive(SnapshotDirectoryToRead); // this is the snapshots directory currently read as a QFileInfo list
             countDirEntries = 0;
             
@@ -144,7 +150,7 @@ void CalcDiffThread::run ()
                 snapFile.remove(SnapshotDirectoryToRead, Qt::CaseSensitive);
 
                 countReturnEntries = 0;
-                bool replaced = FALSE;
+                bool replaced = false;
                 while (countReturnEntries < returnDirContents.size())
                 {
                     QFileInfo localFileInfo = returnDirContents.at(countReturnEntries);
@@ -161,7 +167,7 @@ void CalcDiffThread::run ()
                     {
                         returnDirContents.removeAt(countReturnEntries);
                         returnDirContents.insert(countReturnEntries,snapFileInfo);
-                        replaced = TRUE;
+                        replaced = true;
                     }
                     countReturnEntries++;
                 }
@@ -183,7 +189,7 @@ void CalcDiffThread::run ()
     QList<bool> snapMatchesSource;
     snapMatchesSource.clear();
 
-    emit updateViewer(tr("Scanning source") + "\n\n..." + tr("Please wait"), FALSE);
+    emit updateViewer(tr("Scanning source") + "\n\n..." + tr("Please wait"), false);
     QFileInfoList sourceDirAsList = readRecursive(source);	// This is source as a QFileInfo list
 
     QString calcInfoText = tr("Calculating differences") + "\n\n..." + tr("Please wait") + "\n\n";
@@ -192,14 +198,14 @@ void CalcDiffThread::run ()
     countDirEntries = 0;
     while (countDirEntries < sourceDirAsList.size())
     {
-        bool foundMatchSourceToSnap = FALSE;	// If a file with some filename exists at the source and the snapshot
+        bool foundMatchSourceToSnap = false;	// If a file with some filename exists at the source and the snapshot
         // strip off beginning of source file path
         QFileInfo sourceFileInfo = sourceDirAsList.at(countDirEntries);
         QString sourceFile = sourceFileInfo.filePath();
         if (sourceFile.startsWith(source))
             sourceFile.remove(source, Qt::CaseSensitive);
         
-        emit updateViewer(calcInfoText + countStr.setNum(countDirEntries) + " / " + sourceDirAsListSize, FALSE);		// Give the user sth to watch counting
+        emit updateViewer(calcInfoText + countStr.setNum(countDirEntries) + " / " + sourceDirAsListSize, false);		// Give the user sth to watch counting
         if (abortNOW)
             return;
         
@@ -208,7 +214,7 @@ void CalcDiffThread::run ()
         while (countReturnEntries < returnDirContents.size())
         {
             if (countDirEntries == 0)
-                snapMatchesSource.append(FALSE); // build a <bool> list
+                snapMatchesSource.append(false); // build a <bool> list
 
             //strip off beginning of snapshot file path
             QFileInfo snapFileInfo = returnDirContents.at(countReturnEntries);
@@ -231,8 +237,8 @@ void CalcDiffThread::run ()
             //	The snapshot data will replace the relevant source data, at RESTORE
             if (snapFile == sourceFile)
             {
-                snapMatchesSource.replace(countReturnEntries, TRUE);
-                foundMatchSourceToSnap = TRUE;
+                snapMatchesSource.replace(countReturnEntries, true);
+                foundMatchSourceToSnap = true;
                 if ((snapFileInfo.lastModified() != sourceFileInfo.lastModified()) ||
                 (snapFileInfo.size() != sourceFileInfo.size()))
                 {
@@ -268,7 +274,7 @@ void CalcDiffThread::run ()
     }
 
     // 3. Data that exist at the snapshot but not at the source.
-    // 	These will be transfered over at RESTORE
+    // 	These will be transferred over at RESTORE
     countReturnEntries = 0;
     while (countReturnEntries < snapMatchesSource.size())
     {
@@ -327,7 +333,7 @@ void CalcDiffThread::run ()
         else
         {
             returnString.append(" " + tr("Snapshot data that do NOT exist at the source") + "<br>");
-            returnString.append(" " + tr("These will be transfered over at the source during RESTORE") + "</p>");
+            returnString.append(" " + tr("These will be transferred over at the source during RESTORE") + "</p>");
         }
         returnString.append(existingsnap);
         if (existingsnap.size() > 9900)
