@@ -23,30 +23,28 @@ cpp file that does all stuff needed when a signal is transmitted (eg button pres
 project version	: Please see "main.cpp" for project version
 
 developer       : luckyb 
-last modified   : 10 Feb 2014
+last modified   : 19 Jun 2016
 ===============================================================================================================================
 ===============================================================================================================================
 */
 
-#include <QtGui>
-
-#include "global.cpp"
-
 //inluded headers ---------------------------------------------------------------
 #include "luckybackupwindow.h"
 
-//inluded sources ---------------------------------------------------------------
-#include "textDialog.cpp"
-#include "winDialog.cpp"
-#include "modifyDialog.cpp"
-#include "helpBrowser.cpp"
-#include "scheduleDialog.cpp"
-#include "emailDialog.cpp"
-#include "about.cpp"
-#include "manage.cpp"
-#include "functions.cpp"
-#include "executenow.cpp"
-#include "patternEditor.cpp"
+#include <QProcess>
+#include <QToolBar>
+#include <QCloseEvent>
+#include <QFileDialog>
+
+#include "helpBrowser.h"
+#include "global.h"
+#include "winDialog.h"
+#include "textDialog.h"
+#include "about.h"
+#include "modifyDialog.h"
+#include "manage.h"
+#include "scheduleDialog.h"
+#include "emailDialog.h"
 
 helpBrowser *helpbrowser;
 
@@ -189,7 +187,7 @@ QMessageBox::warning(this, "luckybackup",       "This is a testing version of <b
     ui.textBrowser_info -> setText(InfoData);	//update the info window
 
     if (DryRun)		// if --dry-run was given as an argument, check the relevant box
-        ui.checkBox_DryRun -> setChecked(TRUE);
+        ui.checkBox_DryRun -> setChecked(true);
 
     if (runImmediately)
         start();
@@ -221,7 +219,7 @@ void luckyBackupWindow::exitApp()
     IsVisibleProfileToolbar = profileToolbar -> isVisible();
     IsVisibleProfileStartToolbar = profileStartToolbar -> isVisible();
     saveSettings();
-    exit(0);	//quit
+    QCoreApplication::exit(0);	//quit
 }
 
 //do the same if the main window close button (or alt+F4) is pressed
@@ -237,7 +235,7 @@ void luckyBackupWindow::profileComboChanged()
 {
     if (GoBack)		//if this function is called but shouldn't be executed.
     {
-        GoBack = FALSE;
+        GoBack = false;
         return;
     }
     InfoData = "";
@@ -268,11 +266,11 @@ void luckyBackupWindow::setToolbarAttrs()
     profileToolbar -> setFloatable(!AreToolbarsLocked);
     profileToolbar -> setMovable(!AreToolbarsLocked);
 
-    shutdownToolbar -> setVisible (FALSE);
+    shutdownToolbar -> setVisible (false);
     shutdownToolbar -> setFloatable(!AreToolbarsLocked);
     shutdownToolbar -> setMovable(!AreToolbarsLocked);
     
-    errorsToolbar -> setVisible (FALSE);
+    errorsToolbar -> setVisible (false);
     errorsToolbar -> setFloatable(!AreToolbarsLocked);
     errorsToolbar -> setMovable(!AreToolbarsLocked);
 
@@ -479,7 +477,7 @@ void luckyBackupWindow::deleteCurrentProfile()
 
     if (textdialogQ.getGoOn() > 0)		//if user answers yes
     {
-        savedProfile = TRUE;	//assume the profile is saved
+        savedProfile = true;	//assume the profile is saved
         //try to delete the profile
         if (!profile.remove())
         {
@@ -632,17 +630,17 @@ void luckyBackupWindow::changeProfileDescription()
     ":<br>" + profileDescriptionDisplay);
     
     ui.textBrowser_info -> setText(InfoData);	//update the info window
-    savedProfile = FALSE;			//change profile status to "unsaved"
-    ui.actionSave -> setEnabled(TRUE);
+    savedProfile = false;			//change profile status to "unsaved"
+    ui.actionSave -> setEnabled(true);
 }
 
 // duplicateTask ================================================================================================================================
 // duplicates the current task (creates a new task - same as selected - and opens modify dialog)
 void luckyBackupWindow::duplicateTask()
 {
-    modifyOK = FALSE;
-    modifyConnected = FALSE;
-    newTaskThisIs = TRUE;
+    modifyOK = false;
+    modifyConnected = false;
+    newTaskThisIs = true;
     
     currentOperation = ui.listWidget_operations -> currentRow();		//current task list row number
     if (currentOperation < 0)						//if nothing is selected do nothing
@@ -686,14 +684,14 @@ void luckyBackupWindow::duplicateTask()
     ui.listWidget_operations -> currentItem() -> setCheckState(Qt::Unchecked);
     TotalOperations = ui.listWidget_operations -> count();		//set the TotalOperations to what it is now
 
-    saveOrNot=FALSE;
-    modify();	//open the modify dialog for the new task, FALSE == do not save the result
-    saveOrNot = TRUE;
+    saveOrNot=false;
+    modify();	//open the modify dialog for the new task, false == do not save the result
+    saveOrNot = true;
 
     if (modifyOK)
     {
-        savedProfile = FALSE;			//change profile status to "unsaved"
-        ui.actionSave -> setEnabled(TRUE);
+        savedProfile = false;			//change profile status to "unsaved"
+        ui.actionSave -> setEnabled(true);
     }
     else
     {
@@ -707,7 +705,7 @@ void luckyBackupWindow::duplicateTask()
 //create another operation for RESTORE
 void luckyBackupWindow::AlsoCreateRestore()
 {
-    newTaskThisIs = TRUE;
+    newTaskThisIs = true;
     int oldCurrentOperation = ui.listWidget_operations -> currentRow();	//current task list row number;
 
     if (oldCurrentOperation  < 0)						//if nothing is selected do nothing
@@ -742,7 +740,9 @@ void luckyBackupWindow::AlsoCreateRestore()
 
     //Change its name, source, destination, update checkbox, Remote Host radiobuttons
     Operation[currentOperation] -> SetName ("RESTORE - " + (Operation[currentOperation] -> GetName()));
-    Operation[currentOperation] -> SetOptionsUpdate(FALSE);
+    Operation[currentOperation] -> SetOptionsUpdate(false);
+    Operation[currentOperation] -> SetOptionsDelete(false);
+    Operation[currentOperation] -> SetKeepSnapshots(1);
     Operation[currentOperation] -> SetRemoteDestination(Operation[oldCurrentOperation]-> GetRemoteSource());
     Operation[currentOperation] -> SetRemoteSource(Operation[oldCurrentOperation]-> GetRemoteDestination());
     QString sourceDir	= Operation[oldCurrentOperation] -> GetDestination();
@@ -775,21 +775,21 @@ void luckyBackupWindow::AlsoCreateRestore()
         tr("You have asked for a RESTORE task to be created","'create restore' message line 1/4")+"<br><br>"+
         tr("Please have a good look at the following task properties dialog","'create restore' message line 2/4")+" <br>"+
         tr("and change anything you wish before proceeding","'create restore' message line 3/4")+" <br><br>"+
-        tr("Especially check 'Task name', 'source', 'destination' & 'skip newer destination files' checkbox (advanced)","'create restore' message line 4/4")+"<br>",
+        tr("Please check 'Task name', 'source', 'destination' and especially the 'Delete files on the destination'' & 'skip newer destination files' check-boxes (advanced)","'create restore' message line 4/4")+"<br>",
                 this);
     textdialogW.exec();
 
-    modifyConnected = TRUE;
-    saveOrNot = FALSE;
-    modify();	//open the modify dialog for the new operation to make sure everything is ok, FALSE == do not save the result
-    saveOrNot = TRUE;
+    modifyConnected = true;
+    saveOrNot = false;
+    modify();	//open the modify dialog for the new operation to make sure everything is ok, false == do not save the result
+    saveOrNot = true;
 
     if (modifyOK)		//connect the operation with its RESTORE duplicate
     {
         Operation[currentOperation] -> SetConnectRestore(Operation[oldCurrentOperation] -> GetName());	
         Operation[oldCurrentOperation] -> SetConnectRestore(Operation[currentOperation] -> GetName());
-        savedProfile = FALSE;			//change profile status to "unsaved"
-        ui.actionSave -> setEnabled(TRUE);
+        savedProfile = false;			//change profile status to "unsaved"
+        ui.actionSave -> setEnabled(true);
     }
     else
     {
@@ -916,15 +916,15 @@ void luckyBackupWindow::importProfile()
             + tr("and added at the profile list",
             "full phrase: 'Profile <PROFILENAME> imported successfully as <NEWPROFILENAME> and added at the profile list'") + "</font>");
         if (ExitCodeImportProfile == 30)
-            InfoData.append("<br><font color=red>" + tr("Errors occured during snapshots and logfiles transfer") +"</font>");
+            InfoData.append("<br><font color=red>" + tr("Errors occurred during snapshots and logfiles transfer") +"</font>");
         if (ExitCodeImportProfile == 20) 
-            InfoData.append("<br><font color=red>" + tr("Errors occured during snapshots transfer") +"</font>");
+            InfoData.append("<br><font color=red>" + tr("Errors occurred during snapshots transfer") +"</font>");
         if (ExitCodeImportProfile == 10)
-            InfoData.append("<br><font color=red>" + tr("Errors occured during logfiles transfer") +"</font>");
+            InfoData.append("<br><font color=red>" + tr("Errors occurred during logfiles transfer") +"</font>");
     }
     else    // ExitCodeImportProfile == 1
         InfoData = tr("Failed to import profile","full phrase: 'Failed to import profile <PROFILENAME>'")+" <b>" + importProfileName + 
-                    "</b><br><font color=red>" +tr("Errors occured during the profile file transfer") +"</font>";
+                    "</b><br><font color=red>" +tr("Errors occurred during the profile file transfer") +"</font>";
     ui.textBrowser_info -> setText(InfoData);	//update the info window
 }
 
@@ -939,6 +939,9 @@ void luckyBackupWindow::setLanguage(QAction *action)
         appTranslator.load(QString("luckybackup_") + currentLocale, relativeTransDir);
     else 
         appTranslator.load(QString("luckybackup_") + currentLocale, systemTransDir);
+    
+    translator_qt.load(QString("qt_") + currentLocale,  QLibraryInfo::location(QLibraryInfo::TranslationsPath));
+    
     defaultLanguage = currentLocale;
     retranslateUi();
 }
@@ -953,18 +956,18 @@ void luckyBackupWindow::hideShowInfoWindow()
         ui.pushButton_InfoCollapse -> setToolTip(tr("Hide information window","hide/show information window button tooltip"));
         ui.pushButton_InfoCollapse -> setIcon(QIcon(":/luckyPrefix/collapse.png"));
         if (guiModeNormal)
-            ui.textBrowser_info -> setVisible (TRUE);
+            ui.textBrowser_info -> setVisible (true);
         else
-            ui.nowDoing	-> setVisible (TRUE);
+            ui.nowDoing	-> setVisible (true);
     }
     else
     {
         ui.pushButton_InfoCollapse -> setToolTip(tr("Show information window","hide/show information window button tooltip"));
         ui.pushButton_InfoCollapse -> setIcon(QIcon(":/luckyPrefix/collapseUP.png"));
         if (guiModeNormal)
-            ui.textBrowser_info -> setVisible (FALSE);
+            ui.textBrowser_info -> setVisible (false);
         else
-            ui.nowDoing	-> setVisible (FALSE);
+            ui.nowDoing	-> setVisible (false);
     }
 }
 
@@ -1005,9 +1008,9 @@ void luckyBackupWindow::about()
 // Creates a new operation by calling the modifyDialog
 void luckyBackupWindow::add()
 {
-    modifyOK = FALSE;
-    modifyConnected = FALSE;
-    newTaskThisIs = TRUE;
+    modifyOK = false;
+    modifyConnected = false;
+    newTaskThisIs = true;
     TotalOperations = ui.listWidget_operations -> count();				//Get the Operations list size
     currentOperation = TotalOperations;
 
@@ -1032,8 +1035,8 @@ void luckyBackupWindow::add()
         ui.listWidget_operations -> currentItem() -> setCheckState(Qt::Unchecked);
         checkCurrentItem(ui.listWidget_operations -> currentItem());
         TotalOperations = ui.listWidget_operations -> count();		//set the TotalOperations to what it is now
-        savedProfile = FALSE;			//change profile status to "unsaved"
-        ui.actionSave -> setEnabled(TRUE);
+        savedProfile = false;			//change profile status to "unsaved"
+        ui.actionSave -> setEnabled(true);
     }
 }
 
@@ -1042,8 +1045,8 @@ void luckyBackupWindow::add()
 // Will also save the profile according to saveOrNot
 void luckyBackupWindow::modify()
 {
-    modifyOK = FALSE;
-    newTaskThisIs = FALSE;
+    modifyOK = false;
+    newTaskThisIs = false;
     currentOperation = ui.listWidget_operations -> currentRow();		//current operations list row number
     if (currentOperation < 0)						//if nothing is selected do nothing
     {
@@ -1054,7 +1057,7 @@ void luckyBackupWindow::modify()
 
     QString tempConnect = Operation[currentOperation] -> GetConnectRestore();
     if ( (tempConnect != "") && (!modifyConnected) )	//the operations is connected and is a not new RESTORE operation
-        modifyConnected = TRUE;
+        modifyConnected = true;
     int connectPosition=0;
     if (tempConnect != "")	//if this op is already connected with another op, (pop up a message & )hold the connection's position
     {
@@ -1090,7 +1093,7 @@ void luckyBackupWindow::modify()
         if (newTaskName != oldTaskName)
             arrangeLogSnap(0,"rename",oldTaskName);
         
-        if (saveOrNot)      // also save the current profile if saveOrNot is TRUE
+        if (saveOrNot)      // also save the current profile if saveOrNot is true
             saveCurrentProfile();     
     }
 }
@@ -1152,8 +1155,8 @@ void luckyBackupWindow::remove()
                 currentOperation ++;
             }
         }
-        savedProfile = FALSE;			//change profile status to "unsaved"
-        ui.actionSave -> setEnabled(TRUE);
+        savedProfile = false;			//change profile status to "unsaved"
+        ui.actionSave -> setEnabled(true);
         
         // add the deleted yask name to this list to be used when profile is saved
         deletedTaskNames << oldTaskName;
@@ -1200,8 +1203,8 @@ void luckyBackupWindow::moveUp()
         ui.listWidget_operations -> insertItem(currentOperation - 1, currentItem);
         ui.listWidget_operations -> setCurrentRow(currentOperation - 1);
         
-        savedProfile = FALSE;			//change profile status to "unsaved"
-        ui.actionSave -> setEnabled(TRUE);
+        savedProfile = false;			//change profile status to "unsaved"
+        ui.actionSave -> setEnabled(true);
     }
 }
 
@@ -1225,8 +1228,8 @@ void luckyBackupWindow::moveDown()
         ui.listWidget_operations -> insertItem(currentOperation + 1, currentItem);
         ui.listWidget_operations -> setCurrentRow(currentOperation + 1);
 
-        savedProfile = FALSE;			//change profile status to "unsaved"
-        ui.actionSave -> setEnabled(TRUE);
+        savedProfile = false;			//change profile status to "unsaved"
+        ui.actionSave -> setEnabled(true);
     }
 }
 
@@ -1242,7 +1245,7 @@ void luckyBackupWindow::start()
 
     checkDeclared();		//Check if the declared data are ok by calling checkBackupDirs, checkSyncDirs accordingly
 
-    if (NothingToDo == TRUE)	//if there is nothing to Do anyway then just display a message
+    if (NothingToDo == true)	//if there is nothing to Do anyway then just display a message
     {
         InfoData = "<font color=red><b>" + tr("ERROR") + "</b></font><br>" +
                 "~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~<br><b>" +
@@ -1269,7 +1272,7 @@ void luckyBackupWindow::schedule()
         InfoData = tr("current crontab <font color=green>updated successfully") + "</font>";
     ui.textBrowser_info -> setText(InfoData);
     
-    crontabUpdated = FALSE;		//this is set true each time the crontab is update
+    crontabUpdated = false;		//this is set true each time the crontab is update
 }
 
 // email==========================================================================================================================================
@@ -1284,8 +1287,8 @@ void luckyBackupWindow::email()
         InfoData = tr("Email preferences have been <font color=green>updated successfully") + "</font>";
         ui.textBrowser_info -> setText(InfoData);
         
-        savedProfile = FALSE;           //change profile status to "unsaved"
-        ui.actionSave -> setEnabled(TRUE);
+        savedProfile = false;           //change profile status to "unsaved"
+        ui.actionSave -> setEnabled(true);
     }
     
 }
@@ -1302,27 +1305,27 @@ void luckyBackupWindow::taskStateChanged()
     if (!taskChanged)
     {
         if (taskClicked)
-            taskClicked = FALSE;
+            taskClicked = false;
         else
-            taskChanged = TRUE;
+            taskChanged = true;
         return;
     }
 
     if ( (taskChanged) && (taskClicked) )
     {
-        savedProfile = FALSE;			//change profile status to "unsaved"
-        ui.actionSave -> setEnabled(TRUE);
+        savedProfile = false;			//change profile status to "unsaved"
+        ui.actionSave -> setEnabled(true);
     }
 
-    taskClicked = FALSE;
-    taskChanged = FALSE;
+    taskClicked = false;
+    taskChanged = false;
 }
 
 // checkCurrentItem =================================================================================================================================
 // Checks the currently selected operation (if checked) for validity
 void luckyBackupWindow::checkCurrentItem(QListWidgetItem *thisIsTheCurrentItem)
 {
-    taskClicked = TRUE;	//this is used at taskStateChanged() to determine if a task state is changed
+    taskClicked = true;	//this is used at taskStateChanged() to determine if a task state is changed
 
     InfoData="";
     CheckedData = "";
@@ -1341,14 +1344,14 @@ void luckyBackupWindow::checkCurrentItem(QListWidgetItem *thisIsTheCurrentItem)
     
     if (Operation[currentOperation] -> GetTypeSync())	//if the operation is of type "sync dirs'
     {
-        ui.action_TaskCreateRestore -> setEnabled(FALSE);	//grey out the "create restore task" from menu
+        ui.action_TaskCreateRestore -> setEnabled(false);	//grey out the "create restore task" from menu
         ui.action_TaskManageBackup -> setText(tr("Manage Task","This is a top 'Task' menu action"));
         ui.action_TaskManageBackup -> setToolTip(tr("display information regarding highlighted task",
                             "This is a top 'Task' menu action tooltip"));
     }
     else
     {
-        ui.action_TaskCreateRestore -> setEnabled(TRUE);
+        ui.action_TaskCreateRestore -> setEnabled(true);
         ui.action_TaskManageBackup -> setText(tr("Manage &Backup","This is a top 'Task' menu action"));
         ui.action_TaskManageBackup -> setToolTip(tr("display - restore - delete existing backups of highlighted task",
                             "This is a top 'Task' menu action tooltip"));
@@ -1360,11 +1363,11 @@ void luckyBackupWindow::checkCurrentItem(QListWidgetItem *thisIsTheCurrentItem)
         CheckedData.append(tr("status") + ": <font color=blue><b>"+tr("NOT INCLUDED")+"</font></b><br>");
         CheckedData.append(tr("Checks are disabled. This task will be <b>skipped</b>"));
         ui.textBrowser_info -> setText(CheckedData);
-        Operation[currentOperation] -> SetIncluded(FALSE);	// also set its include state to FALSE
+        Operation[currentOperation] -> SetIncluded(false);	// also set its include state to false
         return;
     }
 
-    Operation[currentOperation] -> SetIncluded(TRUE);	// also set its include state to TRUE
+    Operation[currentOperation] -> SetIncluded(true);	// also set its include state to true
 
     if ( (Operation[currentOperation] -> GetTypeDirContents()) || (Operation[currentOperation] -> GetTypeDirName()) )
         checkBackupDirs(source,dest);			//if the operation is of type "backup dir ...'
