@@ -22,12 +22,20 @@ Class to launch a wizard for restore, delete a backup
 project version    : Please see "main.cpp" for project version
 
 developer          : luckyb 
-last modified      : 10 Nov 2012
+last modified      : 22 May 2016
 ===============================================================================================================================
 ===============================================================================================================================
 */
 #include "manageWizard.h"
-//#include "logDialog.cpp"
+
+#include <QCloseEvent>
+#include <QFileDialog>
+#include <QProcess>
+#include <QTextCodec>
+
+#include "global.h"
+#include "operationClass.h"
+
 QProcess *commandProcess;
 
 // class manageWizard Constructor=================================================================================================
@@ -40,12 +48,12 @@ manageWizard::manageWizard (QString type, QString SOURCE, QString DEST,  int sna
     wizard_type = type;
     snapToRestore = snapshotsNo-2;  // This means the previous of the very last snapshot
     
-    procRunning = FALSE;
-    procKilled = FALSE;
-    writeToLog = FALSE;
-    DeleteAfter = FALSE;
-    firstScroll = TRUE;
-    MainRun = TRUE;
+    procRunning = false;
+    procKilled = false;
+    writeToLog = false;
+    DeleteAfter = false;
+    firstScroll = true;
+    MainRun = true;
     
     QStringList arguments = Operation[currentOperation] -> GetArgs();
     source = SOURCE;	// the full path of the source
@@ -64,9 +72,9 @@ manageWizard::manageWizard (QString type, QString SOURCE, QString DEST,  int sna
 
     QDir snapSpecificDir(dest + snapDefaultDir + time + SLASH);
     if (snapSpecificDir.exists())
-        snapSpecificDirExists = TRUE;
+        snapSpecificDirExists = true;
     else
-        snapSpecificDirExists = FALSE;
+        snapSpecificDirExists = false;
     
     // delete backup;if this are more than one snapshots available, set dir to delete as snapSpecificDir
     if ((wizard_type == "deleteBackup") && (snapshotsNo > 1))
@@ -178,16 +186,16 @@ void manageWizard::startAction()
     DryRun = uiW.checkBox_DryRun -> isChecked();		//set bool DeleteAfter according to checkbox (only applies at RESTORE)
     
     //change the gui
-    uiW.button_next -> setVisible (TRUE);
-    uiW.button_next -> setEnabled (FALSE);
-    uiW.button_previous -> setVisible (TRUE);
-    uiW.button_previous -> setEnabled (FALSE);
-    uiW.actionView -> setVisible (TRUE);
-    uiW.button_cancel -> setVisible (FALSE);
-    uiW.groupBox_title -> setVisible (FALSE);
-    uiW.button_abort -> setVisible (TRUE);
-    uiW.checkBox_DryRun -> setVisible (FALSE);
-    uiW.button_start -> setVisible (FALSE);
+    uiW.button_next -> setVisible (true);
+    uiW.button_next -> setEnabled (false);
+    uiW.button_previous -> setVisible (true);
+    uiW.button_previous -> setEnabled (false);
+    uiW.actionView -> setVisible (true);
+    uiW.button_cancel -> setVisible (false);
+    uiW.groupBox_title -> setVisible (false);
+    uiW.button_abort -> setVisible (true);
+    uiW.checkBox_DryRun -> setVisible (false);
+    uiW.button_start -> setVisible (false);
     
     // logfile actions if real run is performed - is always true for DELETE actions
     //This is the RESTORE/DELETE logfile
@@ -201,9 +209,9 @@ void manageWizard::startAction()
         logfile.setFileName(logfilename); // this is the logfile
         
         if (logfile.open(QIODevice::WriteOnly | QIODevice::Text))	//create a new log file
-            writeToLog = TRUE;				//& if it's ok set this to TRUE
+            writeToLog = true;				//& if it's ok set this to true
         else
-            writeToLog = FALSE;
+            writeToLog = false;
     }
     
     runProcess();
@@ -213,10 +221,10 @@ void manageWizard::startAction()
 // actions when the process is finished
 void manageWizard::procFinished()
 {
-    procRunning = FALSE;
+    procRunning = false;
     if ( (wizard_type == "restoreBackup") && (snapToRestore >= currentSnap ) )
     {
-        MainRun = FALSE;
+        MainRun = false;
 
         time = Operation[currentOperation] -> GetSnapshotsListItem(snapToRestore);
         QString tslash;
@@ -227,9 +235,9 @@ void manageWizard::procFinished()
         QDir snapSpecificDir(dest + snapDefaultDir + time + tslash);
         
         if (snapSpecificDir.exists())
-            snapSpecificDirExists = TRUE;
+            snapSpecificDirExists = true;
         else
-            snapSpecificDirExists = FALSE;
+            snapSpecificDirExists = false;
         
         snapToRestore--;
         
@@ -241,13 +249,13 @@ void manageWizard::procFinished()
     
     errorsFound = errorCount;
     errorCount = 0;		// reset the error count
-    uiW.button_abort -> setVisible (FALSE);
-    uiW.button_cancel -> setVisible (TRUE);
+    uiW.button_abort -> setVisible (false);
+    uiW.button_cancel -> setVisible (true);
     uiW.button_cancel -> setText(tr("close"));
     if (errorsFound > 0)
     {
-        firstScroll=TRUE;
-        uiW.button_next -> setEnabled (TRUE);
+        firstScroll=true;
+        uiW.button_next -> setEnabled (true);
     }
     
     // if delete backup just finished normally (not ABORTED) with no errors
@@ -326,8 +334,8 @@ void manageWizard::abortAction()
 {
     if (commandProcess->state() == QProcess::Running)
     {
-        procKilled = TRUE;
-        MainRun = FALSE;
+        procKilled = true;
+        MainRun = false;
         commandProcess -> kill();	//kill commandProcess
         commandProcess -> waitForFinished();
     }
@@ -379,10 +387,10 @@ void manageWizard::prevError()
     errorCount--;		//decrease the current error by one
 
     if (errorCount == 0 )		// if the current error is the first disable the previous button
-        uiW.button_previous -> setEnabled(FALSE);
+        uiW.button_previous -> setEnabled(false);
     
     if (errorCount < errorsFound-1)	//if the current error is less than the last one, enable the next button
-        uiW.button_next -> setEnabled(TRUE);
+        uiW.button_next -> setEnabled(true);
     
     uiW.actionView -> scrollToAnchor("error" + countStr.setNum(errorCount+1));
 }
@@ -393,13 +401,13 @@ void manageWizard::nextError()
 {
     if (!firstScroll)
         errorCount++;	// increase the current error by one
-    firstScroll = FALSE;
+    firstScroll = false;
     
     if (errorCount == errorsFound-1)		// If the current error is the last, disable the next button
-        uiW.button_next -> setEnabled(FALSE);
+        uiW.button_next -> setEnabled(false);
     
     if (errorCount > 0)				// if the current error is greater than the first one enable the previous button
-        uiW.button_previous -> setEnabled(TRUE);
+        uiW.button_previous -> setEnabled(true);
     
     uiW.actionView -> scrollToAnchor("error" + countStr.setNum(errorCount+1));
 }
@@ -410,10 +418,10 @@ void manageWizard::nextError()
 // Initialize the gui
 void manageWizard::guiInitialize()
 {
-    uiW.button_next -> setVisible (FALSE);
-    uiW.button_previous -> setVisible (FALSE);
-    uiW.button_abort -> setVisible (FALSE);
-    uiW.actionView -> setVisible (FALSE);
+    uiW.button_next -> setVisible (false);
+    uiW.button_previous -> setVisible (false);
+    uiW.button_abort -> setVisible (false);
+    uiW.actionView -> setVisible (false);
     
     if (wizard_type == "deleteBackup")
     {	
@@ -426,9 +434,9 @@ void manageWizard::guiInitialize()
                     tr("If the information above is correct, click <b>start</b> to begin",
                     "information message - line2.\nPlease leave tags <b></b> intact and surrounding 'start' translated") +
                     ".");
-        uiW.checkBox_DryRun -> setVisible (FALSE);
-        uiW.checkBox_DeleteAfter -> setVisible (FALSE);
-        uiW.pushButton_changeRestore -> setVisible (FALSE);
+        uiW.checkBox_DryRun -> setVisible (false);
+        uiW.checkBox_DeleteAfter -> setVisible (false);
+        uiW.pushButton_changeRestore -> setVisible (false);
     }
     if (wizard_type == "restoreBackup")
     {
@@ -524,7 +532,7 @@ void manageWizard::calcCommandArgs()
 // Run the desired process
 void manageWizard::runProcess()
 {
-    bool skipTHIS = FALSE;
+    bool skipTHIS = false;
     
     // specify command & arguments & append information message
     QString commandLocal =""; commandArguments.clear();   // the local command is used here !!
@@ -541,7 +549,7 @@ void manageWizard::runProcess()
         {
             InfoMessage.append(tr("Restoring data: snapshot files","info message displayed during ...data restoration") + " - " + time);
             if (!snapSpecificDirExists)
-                skipTHIS = TRUE;
+                skipTHIS = true;
         }
         if (DryRun)
             InfoMessage.append(" (" + tr("simulation") + ")");
@@ -556,7 +564,7 @@ void manageWizard::runProcess()
             commandArguments << "-rvf" << dest;
         }
         else
-            skipTHIS = TRUE;
+            skipTHIS = true;
         
     }
 
@@ -580,7 +588,7 @@ void manageWizard::runProcess()
     {
         commandProcess -> start (commandLocal,commandArguments);
         commandProcess -> waitForStarted();
-        procRunning = TRUE;
+        procRunning = true;
     }
 }
 // end of managewizard.cpp ---------------------------------------------------------------------------
