@@ -23,7 +23,7 @@ Display a dialog. Adds a new or modifies an existing operation
  project version    : Please see "main.cpp" for project version
 
  developer          : luckyb 
- last modified      : 12 Jan 2014
+ last modified      : 05 Oct 2017
 
 ===============================================================================================================================
 ===============================================================================================================================
@@ -31,6 +31,15 @@ Display a dialog. Adds a new or modifies an existing operation
 
 #include "modifyDialog.h"
 
+#include <QSignalMapper>
+#include <QCompleter>
+#include <QDirModel>
+#include <QFileDialog>
+
+#include "global.h"
+
+#include "textDialog.h"
+
 // class modifyDialog Constructor=================================================================================================
 // modify or create an operation
 modifyDialog::modifyDialog (int ItemNo, QDialog *parent) : QDialog (parent)
@@ -38,14 +47,15 @@ modifyDialog::modifyDialog (int ItemNo, QDialog *parent) : QDialog (parent)
     uiM.setupUi(this);
 
     stdWindowWidth = 540;
-    minWindowHeight = 245;
-    maxWindowHeight = 565;
-    uiM.tabWidget_advanced -> setVisible(FALSE);
+    minWindowHeight = 265;      //old value=245
+    maxWindowHeight = 690;      //old value=565
+
+    uiM.tabWidget_advanced -> setVisible(false);
     uiM.comboBox_Type -> setCurrentIndex(0);
     this -> resize(stdWindowWidth,minWindowHeight);
     ArrayPosition = ItemNo;
-    validation = FALSE;
-    listItemEditMode = FALSE;
+    validation = false;
+    listItemEditMode = false;
         
     alsoExecuteTooltip = tr("Leave the box checked, to <b>STOP</b> the execution of running task if this command exits with an error");
     QString comLabel= tr("use boxes to <b>STOP</b> task execution on error", "Please leave the bold tags <b></b> intact and surrounding the word STOP translated");
@@ -54,18 +64,20 @@ modifyDialog::modifyDialog (int ItemNo, QDialog *parent) : QDialog (parent)
     
     //~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
     // Various gui initialization
-    //uiM.toolBox_options         ->setItemEnabled (0,FALSE);    // different backend
+    //uiM.toolBox_options         ->setItemEnabled (0,false);    // different backend
     
     //Disable some stuff when windows is NOT running
     if (!WINrunning)
     {
-        uiM.checkBox_vss        -> setVisible(FALSE);
-        uiM.checkBox_restorent  -> setVisible(FALSE);
-        uiM.lineEdit_sshPasswordStr -> setVisible(FALSE);
-        uiM.lineEdit_sshOptions -> setVisible(FALSE);
+        uiM.checkBox_vss        -> setVisible(false);
+        uiM.checkBox_restorent  -> setVisible(false);
+        uiM.lineEdit_sshPasswordStr -> setVisible(false);
+        uiM.lineEdit_sshOptions -> setVisible(false);
+        uiM.label_sshPassword_2 -> setVisible(false);
+        uiM.label_sshPassword_2 -> setVisible(false);
     }
     else
-        uiM.checkBox_vss        -> setEnabled(FALSE);   // disable VSS until a better solution is found
+        uiM.checkBox_vss        -> setEnabled(false);   // disable VSS until a better solution is found
     
     //~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
 
@@ -231,13 +243,13 @@ void modifyDialog::advancedPressed(bool advanced)
     int windowWidth = (this -> size()).width();
     if (advanced)
     {
-        uiM.tabWidget_advanced -> setVisible(TRUE);
+        uiM.tabWidget_advanced -> setVisible(true);
         uiM.pushButton_advanced -> setText(tr("simple"));
         this -> resize(windowWidth,maxWindowHeight);
     }
     else
     {
-        uiM.tabWidget_advanced -> setVisible(FALSE);
+        uiM.tabWidget_advanced -> setVisible(false);
         uiM.pushButton_advanced -> setText(tr("advanced"));
         this -> resize(windowWidth,minWindowHeight);
     }
@@ -246,8 +258,8 @@ void modifyDialog::advancedPressed(bool advanced)
 // cancel button pressed=====================================================================================================
 void modifyDialog::cancelPressed()
 {
-    modifyOK = FALSE;
-    modifyConnected = FALSE;
+    modifyOK = false;
+    modifyConnected = false;
     close();    //emmit a QcloseEvent
 }
 
@@ -354,7 +366,7 @@ void modifyDialog::getPattern(const int type)
 // ...after performing some checks & changes !!
 void modifyDialog::okayPressed()
 {
-    modifyOK = TRUE;
+    modifyOK = true;
     message = "";
     
     // Strip off invalid characters from task name
@@ -363,8 +375,8 @@ void modifyDialog::okayPressed()
     //if name or source or destination is missing do not proceed -----------------------------------------------------------
     if ( (uiM.lineEdit_name -> text() == "") || (uiM.lineEdit_destination -> text() == "") || (uiM.lineEdit_source -> text() == "")  )
     {
-        modifyOK = FALSE;
-        message.append("<b>"+tr("ERROR","message box message")+":</b> "+
+        modifyOK = false;
+        message.append(/*"<b>"+tr("ERROR","message box message")+":</b> "+*/
                     tr("Please specify the following before proceeding:","message box, message"));
         if (uiM.lineEdit_name -> text() == "")
             message.append("<br>"+tr("Task name"));
@@ -378,8 +390,8 @@ void modifyDialog::okayPressed()
     //check if / is declared as source and backup dir by name as operation type ------------------------------------------------
     if ((uiM.lineEdit_source -> text() == "/") && (uiM.comboBox_Type -> currentIndex()==0) && (!uiM.checkBox_backupContents -> isChecked()))
     {
-        modifyOK = FALSE;
-        message.append("<b>"+tr("ERROR","message box message - line1")+":</b> "+
+        modifyOK = false;
+        message.append(/*"<b>"+tr("ERROR","message box message - line1")+":</b> "+*/
         tr("You have declared the '/' (root) directory as source and have NOT checked the 'Do NOT create extra directory' box","message box message - line1")+"<br>"+
                 tr("That is not allowed because '/' does not have an actual name","message box message - line2")+" !!<br>"
                 "..."+tr("Please check the relevant box before proceeding","message box message - line3")+"<br><br>");
@@ -388,8 +400,8 @@ void modifyDialog::okayPressed()
     if (((uiM.lineEdit_source -> text()).endsWith(":\\")) && (uiM.comboBox_Type -> currentIndex()==0) && (!uiM.checkBox_backupContents -> isChecked())
         && (notXnixRunning) )
     {
-        modifyOK = FALSE;
-        message.append("<b>"+tr("ERROR","message box message - line1")+":</b> "+
+        modifyOK = false;
+        message.append(/*"<b>"+tr("ERROR","message box message - line1")+":</b> "+*/
         tr("You have declared the root directory of an entire partition as source and have NOT checked the 'Do NOT create extra directory' box","message box message - line1")+"<br>"+
                 tr("That is not allowed because the root partition does not have an actual name","message box message - line2")+" !!<br>"
                 "..."+tr("Please check the relevant box before proceeding","message box message - line3")+"<br><br>");
@@ -401,8 +413,8 @@ void modifyDialog::okayPressed()
     {
         if ( ((uiM.lineEdit_name -> text()) == (Operation[count] -> GetName()) ) && (count != ArrayPosition) )
         {
-            modifyOK = FALSE;
-            message.append("<b>"+tr("ERROR","message box message - line1")+":</b> "+
+            modifyOK = false;
+            message.append(/*"<b>"+tr("ERROR","message box message - line1")+":</b> "+*/
             tr("The name of the task you requested already exists","message box message - line1")+" !!<br>"
                     "..."+tr("Please specify a different name before proceeding","message box message - line2")+"<br><br>");
             break;
@@ -419,15 +431,15 @@ void modifyDialog::okayPressed()
         if ((( (uiM.lineEdit_source -> text()) == (uiM.lineEdit_destination -> text()) )    
         || ( (uiM.lineEdit_source -> text() + SLASH) == (uiM.lineEdit_destination -> text()) )    ) && (!uiM.groupBox_remote -> isChecked()) )
         {
-            modifyOK = FALSE;
-            message.append("<b>"+tr("ERROR","message box message - line1")+":</b> "+
+            modifyOK = false;
+            message.append(/*"<b>"+tr("ERROR","message box message - line1")+":</b> "+*/
             tr("The source you have declared is identical to the destination","message box message - line1")+" !!<br>"
                     "..."+tr("Please modify at least one of them","message box message - line2")+"<br><br>");
         }
         else    //check if the destination is part of the source directory structure ------------------------------------------------
         if (     ((uiM.lineEdit_destination -> text()).contains(uiM.lineEdit_source -> text(), Qt::CaseSensitive) )
         ||    ((uiM.lineEdit_destination -> text()).contains(uiM.lineEdit_source -> text() + SLASH, Qt::CaseSensitive))    )
-                message.prepend("<b>"+tr("WARNING","message box message - line1")+":</b> "+
+                message.prepend(/*"<b>"+tr("WARNING","message box message - line1")+":</b> "+*/
                     tr("You have declared a destination that is part of the source directory structure",
                        "message box message - line1")+"<br>"
                     +tr("<b>Do not forget</b> to define a directory at the 'exclude' groupbox that will contain the destination",
@@ -437,8 +449,8 @@ void modifyDialog::okayPressed()
     //"recursive" has to be checked for --delete-after to operate -------------------------------------------------------------
     if ( (uiM.checkBox_deleteAfter -> isChecked()) && !(uiM.checkBox_recurse -> isChecked()) )
     {
-        modifyOK = FALSE;
-        message.append("<b>"+tr("ERROR","message box message - line1")+":</b> "+
+        modifyOK = false;
+        message.append(/*"<b>"+tr("ERROR","message box message - line1")+":</b> "+*/
         tr("You have checked the 'delete files on the destination' option","message box message - line2") + "<br>" +
                 tr("without having checked 'Recurse into directories' which is required","message box message - line3")+"<br><br>");
     }
@@ -446,15 +458,15 @@ void modifyDialog::okayPressed()
     //check if "remote" is checked and no hostname is declared -----------------------------------------------------------------
     if ( (uiM.groupBox_remote -> isChecked()) && (uiM.lineEdit_remoteHost -> text() == "") )
     {
-        modifyOK = FALSE;
-        message.append("<b>"+tr("ERROR","message box message - line1")+":</b>"+
+        modifyOK = false;
+        message.append(/*"<b>"+tr("ERROR","message box message - line1")+":</b>"+*/
                 tr("'Remote Host' is checked, but no remote host name is declared","message box message - line2")+"<br>"+
                 tr("Please specify a remote host name","message box message - line3")+"<br>"+
                 tr("Otherwise uncheck 'Remote Host' to operate locally","message box message - line4")+"<br><br>");
     }
 
-    bool tempCloneWarning = TRUE;
-    //use this cause the next command will set CloneWARNING to TRUE by creating a new operation
+    bool tempCloneWarning = true;
+    //use this cause the next command will set CloneWARNING to true by creating a new operation
     // only perform this if "modify is pressed, not "new/duplicate/restore" task
     if (!newTaskThisIs)
         tempCloneWarning = Operation[ArrayPosition] -> GetCloneWARNING ();
@@ -474,7 +486,7 @@ void modifyDialog::okayPressed()
                 textdialog.exec();
                 if (textdialog.getGoOn() == 4)        //okay with "Do not show this again" checked
                 {
-                    Operation[ArrayPosition] -> SetCloneWARNING (FALSE);
+                    Operation[ArrayPosition] -> SetCloneWARNING (false);
                     close();
                 }
                 if (textdialog.getGoOn() == 2)        //okay with "Do not show this again" NOT checked
@@ -495,7 +507,7 @@ void modifyDialog::okayPressed()
 // Pops up a dialog with the rsync command & arguments, also displays error messages
 void modifyDialog::commandPressed()
 {
-    validation = TRUE;
+    validation = true;
 
     okayPressed();
     
@@ -524,7 +536,7 @@ void modifyDialog::commandPressed()
         "</font><br><font color=magenta>"+ source + " </font><br><font color=magenta>" + dest + "</font><br>", this);
     textdialog.exec();
 
-    validation = FALSE;
+    validation = false;
     //==========================================================================================================================
 }
 
@@ -579,12 +591,12 @@ void modifyDialog::addListItem(const int type)
                 uiM.pushButton_excludeRemove -> setToolTip(origRemoveToolTip);
                 uiM.pushButton_excludeRemove -> setIcon(QIcon(":/luckyPrefix/remove.png"));
                 
-                uiM.pushButton_editExclude -> setEnabled (TRUE);
-                uiM.pushButton_moveUpExclude -> setEnabled (TRUE);
-                uiM.pushButton_moveDownExclude -> setEnabled (TRUE);
+                uiM.pushButton_editExclude -> setEnabled (true);
+                uiM.pushButton_moveUpExclude -> setEnabled (true);
+                uiM.pushButton_moveDownExclude -> setEnabled (true);
                 
-                // set this bool var to FALSE - end of list edit mode
-                listItemEditMode = FALSE;
+                // set this bool var to false - end of list edit mode
+                listItemEditMode = false;
             }
             else
                 uiM.listWidget_exclude -> addItem(text);
@@ -634,12 +646,12 @@ void modifyDialog::addListItem(const int type)
                 uiM.pushButton_includeRemove -> setToolTip(origRemoveToolTip);
                 uiM.pushButton_includeRemove -> setIcon(QIcon(":/luckyPrefix/remove.png"));
                 
-                uiM.pushButton_editInclude -> setEnabled (TRUE);
-                uiM.pushButton_moveUpInclude -> setEnabled (TRUE);
-                uiM.pushButton_moveDownInclude -> setEnabled (TRUE);
+                uiM.pushButton_editInclude -> setEnabled (true);
+                uiM.pushButton_moveUpInclude -> setEnabled (true);
+                uiM.pushButton_moveDownInclude -> setEnabled (true);
                 
-                // set this bool var to FALSE - end of list edit mode
-                listItemEditMode = FALSE;
+                // set this bool var to false - end of list edit mode
+                listItemEditMode = false;
             }
             else
                 uiM.listWidget_include -> addItem(text);
@@ -687,12 +699,12 @@ void modifyDialog::addListItem(const int type)
                 uiM.pushButton_optionsRemove -> setToolTip(origRemoveToolTip);
                 uiM.pushButton_optionsRemove -> setIcon(QIcon(":/luckyPrefix/remove.png"));
                 
-                uiM.pushButton_editOptions -> setEnabled (TRUE);
-                uiM.pushButton_moveUpOptions -> setEnabled (TRUE);
-                uiM.pushButton_moveDownOptions -> setEnabled (TRUE);
+                uiM.pushButton_editOptions -> setEnabled (true);
+                uiM.pushButton_moveUpOptions -> setEnabled (true);
+                uiM.pushButton_moveDownOptions -> setEnabled (true);
                 
-                // set this bool var to FALSE - end of list edit mode
-                listItemEditMode = FALSE;
+                // set this bool var to false - end of list edit mode
+                listItemEditMode = false;
             }
             else
                 uiM.listWidget_options -> addItem(text);
@@ -725,12 +737,12 @@ void modifyDialog::addListItem(const int type)
                     uiM.pushButton_executeBeforeRemove -> setToolTip(origRemoveToolTip);
                     uiM.pushButton_executeBeforeRemove -> setIcon(QIcon(":/luckyPrefix/remove.png"));
                     
-                    uiM.pushButton_editExecuteBefore -> setEnabled (TRUE);
-                    uiM.pushButton_moveUpExecuteBefore -> setEnabled (TRUE);
-                    uiM.pushButton_moveDownExecuteBefore -> setEnabled (TRUE);
+                    uiM.pushButton_editExecuteBefore -> setEnabled (true);
+                    uiM.pushButton_moveUpExecuteBefore -> setEnabled (true);
+                    uiM.pushButton_moveDownExecuteBefore -> setEnabled (true);
                     
-                    // set this bool var to FALSE - end of list edit mode
-                    listItemEditMode = FALSE;
+                    // set this bool var to false - end of list edit mode
+                    listItemEditMode = false;
                 }
                 else
                 {
@@ -767,12 +779,12 @@ void modifyDialog::addListItem(const int type)
                     uiM.pushButton_executeAfterRemove -> setToolTip(origRemoveToolTip);
                     uiM.pushButton_executeAfterRemove -> setIcon(QIcon(":/luckyPrefix/remove.png"));
                     
-                    uiM.pushButton_editExecuteAfter -> setEnabled (TRUE);
-                    uiM.pushButton_moveUpExecuteAfter -> setEnabled (TRUE);
-                    uiM.pushButton_moveDownExecuteAfter -> setEnabled (TRUE);
+                    uiM.pushButton_editExecuteAfter -> setEnabled (true);
+                    uiM.pushButton_moveUpExecuteAfter -> setEnabled (true);
+                    uiM.pushButton_moveDownExecuteAfter -> setEnabled (true);
                     
-                    // set this bool var to FALSE - end of list edit mode
-                    listItemEditMode = FALSE;
+                    // set this bool var to false - end of list edit mode
+                    listItemEditMode = false;
                 }
                 else
                 {
@@ -806,10 +818,10 @@ void modifyDialog::removeListItem(const int type)
                 uiM.pushButton_excludeRemove -> setText(origRemoveText);
                 uiM.pushButton_excludeRemove -> setToolTip(origRemoveToolTip);
                 uiM.pushButton_excludeRemove -> setIcon(QIcon(":/luckyPrefix/remove.png"));
-                uiM.pushButton_editExclude -> setEnabled (TRUE);
-                uiM.pushButton_moveUpExclude -> setEnabled (TRUE);
-                uiM.pushButton_moveDownExclude -> setEnabled (TRUE);
-                listItemEditMode = FALSE;   // set this bool var to FALSE - end of list edit mode
+                uiM.pushButton_editExclude -> setEnabled (true);
+                uiM.pushButton_moveUpExclude -> setEnabled (true);
+                uiM.pushButton_moveDownExclude -> setEnabled (true);
+                listItemEditMode = false;   // set this bool var to false - end of list edit mode
                 return;
             }
             
@@ -829,10 +841,10 @@ void modifyDialog::removeListItem(const int type)
                 uiM.pushButton_includeRemove -> setText(origRemoveText);
                 uiM.pushButton_includeRemove -> setToolTip(origRemoveToolTip);
                 uiM.pushButton_includeRemove -> setIcon(QIcon(":/luckyPrefix/remove.png"));
-                uiM.pushButton_editInclude -> setEnabled (TRUE);
-                uiM.pushButton_moveUpInclude -> setEnabled (TRUE);
-                uiM.pushButton_moveDownInclude -> setEnabled (TRUE);
-                listItemEditMode = FALSE;   // set this bool var to FALSE - end of list edit mode
+                uiM.pushButton_editInclude -> setEnabled (true);
+                uiM.pushButton_moveUpInclude -> setEnabled (true);
+                uiM.pushButton_moveDownInclude -> setEnabled (true);
+                listItemEditMode = false;   // set this bool var to false - end of list edit mode
                 return;
             }
             
@@ -853,10 +865,10 @@ void modifyDialog::removeListItem(const int type)
                 uiM.pushButton_optionsRemove -> setText(origRemoveText);
                 uiM.pushButton_optionsRemove -> setToolTip(origRemoveToolTip);
                 uiM.pushButton_optionsRemove -> setIcon(QIcon(":/luckyPrefix/remove.png"));
-                uiM.pushButton_editOptions -> setEnabled (TRUE);
-                uiM.pushButton_moveUpOptions -> setEnabled (TRUE);
-                uiM.pushButton_moveDownOptions -> setEnabled (TRUE);
-                listItemEditMode = FALSE;   // set this bool var to FALSE - end of list edit mode
+                uiM.pushButton_editOptions -> setEnabled (true);
+                uiM.pushButton_moveUpOptions -> setEnabled (true);
+                uiM.pushButton_moveDownOptions -> setEnabled (true);
+                listItemEditMode = false;   // set this bool var to false - end of list edit mode
                 return;
             }
             
@@ -876,10 +888,10 @@ void modifyDialog::removeListItem(const int type)
                 uiM.pushButton_executeBeforeRemove -> setText(origRemoveText);
                 uiM.pushButton_executeBeforeRemove -> setToolTip(origRemoveToolTip);
                 uiM.pushButton_executeBeforeRemove -> setIcon(QIcon(":/luckyPrefix/remove.png"));
-                uiM.pushButton_editExecuteBefore -> setEnabled (TRUE);
-                uiM.pushButton_moveUpExecuteBefore -> setEnabled (TRUE);
-                uiM.pushButton_moveDownExecuteBefore -> setEnabled (TRUE);
-                listItemEditMode = FALSE;   // set this bool var to FALSE - end of list edit mode
+                uiM.pushButton_editExecuteBefore -> setEnabled (true);
+                uiM.pushButton_moveUpExecuteBefore -> setEnabled (true);
+                uiM.pushButton_moveDownExecuteBefore -> setEnabled (true);
+                listItemEditMode = false;   // set this bool var to false - end of list edit mode
                 return;
             }
             
@@ -899,10 +911,10 @@ void modifyDialog::removeListItem(const int type)
                 uiM.pushButton_executeAfterRemove -> setText(origRemoveText);
                 uiM.pushButton_executeAfterRemove -> setToolTip(origRemoveToolTip);
                 uiM.pushButton_executeAfterRemove -> setIcon(QIcon(":/luckyPrefix/remove.png"));
-                uiM.pushButton_editExecuteAfter -> setEnabled (TRUE);
-                uiM.pushButton_moveUpExecuteAfter -> setEnabled (TRUE);
-                uiM.pushButton_moveDownExecuteAfter -> setEnabled (TRUE);
-                listItemEditMode = FALSE;   // set this bool var to FALSE - end of list edit mode
+                uiM.pushButton_editExecuteAfter -> setEnabled (true);
+                uiM.pushButton_moveUpExecuteAfter -> setEnabled (true);
+                uiM.pushButton_moveDownExecuteAfter -> setEnabled (true);
+                listItemEditMode = false;   // set this bool var to false - end of list edit mode
                 return;
             }
     
@@ -927,7 +939,7 @@ void modifyDialog::editListItem(const int type)
         case 0: selected = uiM.listWidget_exclude -> currentRow();              //current list row number
             if (selected < 0)                           //if nothing is selected do nothing
                 return;
-            listItemEditMode = TRUE;
+            listItemEditMode = true;
             origAddText = uiM.pushButton_excludeAdd -> text();
             origAddToolTip = uiM.pushButton_excludeAdd -> toolTip();
             origRemoveText = uiM.pushButton_excludeRemove -> text();
@@ -939,9 +951,9 @@ void modifyDialog::editListItem(const int type)
             uiM.pushButton_excludeRemove -> setToolTip(tr("cancel editing"));
             uiM.pushButton_excludeRemove -> setIcon(QIcon(":/luckyPrefix/cancel.png"));
             
-            uiM.pushButton_editExclude -> setEnabled (FALSE);
-            uiM.pushButton_moveUpExclude -> setEnabled (FALSE);
-            uiM.pushButton_moveDownExclude -> setEnabled (FALSE);
+            uiM.pushButton_editExclude -> setEnabled (false);
+            uiM.pushButton_moveUpExclude -> setEnabled (false);
+            uiM.pushButton_moveDownExclude -> setEnabled (false);
             
             selectedText = (uiM.listWidget_exclude -> currentItem()) -> text();  //current list item text
             uiM.lineEdit_excludeAdd -> setText (selectedText);
@@ -952,7 +964,7 @@ void modifyDialog::editListItem(const int type)
         case 1: selected = uiM.listWidget_include -> currentRow();          //current list row number
             if (selected < 0)                           //if nothing is selected do nothing
                 return;
-            listItemEditMode = TRUE;
+            listItemEditMode = true;
             origAddText = uiM.pushButton_includeAdd -> text();
             origAddToolTip = uiM.pushButton_includeAdd -> toolTip();
             origRemoveText = uiM.pushButton_includeRemove -> text();
@@ -964,9 +976,9 @@ void modifyDialog::editListItem(const int type)
             uiM.pushButton_includeRemove -> setToolTip(tr("cancel editing"));
             uiM.pushButton_includeRemove -> setIcon(QIcon(":/luckyPrefix/cancel.png"));
             
-            uiM.pushButton_editInclude -> setEnabled (FALSE);
-            uiM.pushButton_moveUpInclude -> setEnabled (FALSE);
-            uiM.pushButton_moveDownInclude -> setEnabled (FALSE);
+            uiM.pushButton_editInclude -> setEnabled (false);
+            uiM.pushButton_moveUpInclude -> setEnabled (false);
+            uiM.pushButton_moveDownInclude -> setEnabled (false);
             
             selectedText = (uiM.listWidget_include -> currentItem()) -> text();  //current list item text
             uiM.lineEdit_includeAdd -> setText (selectedText);
@@ -977,7 +989,7 @@ void modifyDialog::editListItem(const int type)
         case 2: selected = uiM.listWidget_options -> currentRow();          //current list row number
             if (selected < 0)                           //if nothing is selected do nothing
                 return;
-            listItemEditMode = TRUE;
+            listItemEditMode = true;
             origAddText = uiM.pushButton_optionsAdd -> text();
             origAddToolTip = uiM.pushButton_optionsAdd -> toolTip();
             origRemoveText = uiM.pushButton_optionsRemove -> text();
@@ -989,9 +1001,9 @@ void modifyDialog::editListItem(const int type)
             uiM.pushButton_optionsRemove -> setToolTip(tr("cancel editing"));
             uiM.pushButton_optionsRemove -> setIcon(QIcon(":/luckyPrefix/cancel.png"));
             
-            uiM.pushButton_editOptions -> setEnabled (FALSE);
-            uiM.pushButton_moveUpOptions -> setEnabled (FALSE);
-            uiM.pushButton_moveDownOptions -> setEnabled (FALSE);
+            uiM.pushButton_editOptions -> setEnabled (false);
+            uiM.pushButton_moveUpOptions -> setEnabled (false);
+            uiM.pushButton_moveDownOptions -> setEnabled (false);
             
             selectedText = (uiM.listWidget_options -> currentItem()) -> text();  //current list item text
             uiM.lineEdit_optionsAdd -> setText (selectedText);
@@ -1002,7 +1014,7 @@ void modifyDialog::editListItem(const int type)
         case 3: selected = uiM.listWidget_executeBefore  -> currentRow();       //current list row number
             if (selected < 0)                           //if nothing is selected do nothing
                 return;
-            listItemEditMode = TRUE;
+            listItemEditMode = true;
             origAddText = uiM.pushButton_executeBeforeAdd -> text();
             origAddToolTip = uiM.pushButton_executeBeforeAdd -> toolTip();
             origRemoveText = uiM.pushButton_executeBeforeRemove -> text();
@@ -1014,9 +1026,9 @@ void modifyDialog::editListItem(const int type)
             uiM.pushButton_executeBeforeRemove -> setToolTip(tr("cancel editing"));
             uiM.pushButton_executeBeforeRemove -> setIcon(QIcon(":/luckyPrefix/cancel.png"));
             
-            uiM.pushButton_editExecuteBefore -> setEnabled (FALSE);
-            uiM.pushButton_moveUpExecuteBefore -> setEnabled (FALSE);
-            uiM.pushButton_moveDownExecuteBefore -> setEnabled (FALSE);
+            uiM.pushButton_editExecuteBefore -> setEnabled (false);
+            uiM.pushButton_moveUpExecuteBefore -> setEnabled (false);
+            uiM.pushButton_moveDownExecuteBefore -> setEnabled (false);
             
             selectedText = (uiM.listWidget_executeBefore -> currentItem()) -> text();  //current list item text
             alsoExecuteState = uiM.listWidget_executeBefore -> currentItem() -> checkState();   // current list item check state
@@ -1028,7 +1040,7 @@ void modifyDialog::editListItem(const int type)
         case 4: selected = uiM.listWidget_executeAfter -> currentRow();         //current list row number
             if (selected < 0)                           //if nothing is selected do nothing
                 return;
-            listItemEditMode = TRUE;
+            listItemEditMode = true;
             origAddText = uiM.pushButton_executeAfterAdd -> text();
             origAddToolTip = uiM.pushButton_executeAfterAdd -> toolTip();
             origRemoveText = uiM.pushButton_executeAfterRemove -> text();
@@ -1040,9 +1052,9 @@ void modifyDialog::editListItem(const int type)
             uiM.pushButton_executeAfterRemove -> setToolTip(tr("cancel editing"));
             uiM.pushButton_executeAfterRemove -> setIcon(QIcon(":/luckyPrefix/cancel.png"));
             
-            uiM.pushButton_editExecuteAfter -> setEnabled (FALSE);
-            uiM.pushButton_moveUpExecuteAfter -> setEnabled (FALSE);
-            uiM.pushButton_moveDownExecuteAfter -> setEnabled (FALSE);
+            uiM.pushButton_editExecuteAfter -> setEnabled (false);
+            uiM.pushButton_moveUpExecuteAfter -> setEnabled (false);
+            uiM.pushButton_moveDownExecuteAfter -> setEnabled (false);
             
             selectedText = (uiM.listWidget_executeAfter -> currentItem()) -> text();  //current list item text
             alsoExecuteState = uiM.listWidget_executeAfter -> currentItem() -> checkState();   // current list item check state
@@ -1198,31 +1210,31 @@ void modifyDialog::TaskTypeChanged(int type)
 {
     if (type == 1)
     {
-        uiM.label_snapshotsKeep -> setVisible(FALSE);
-        uiM.spinBox_snapshotsKeep -> setVisible(FALSE);
-        uiM.checkBox_backupContents -> setVisible(FALSE);
-        uiM.checkBox_deleteAfter -> setEnabled (FALSE);
+        uiM.label_snapshotsKeep -> setVisible(false);
+        uiM.spinBox_snapshotsKeep -> setVisible(false);
+        uiM.checkBox_backupContents -> setVisible(false);
+        uiM.checkBox_deleteAfter -> setEnabled (false);
     }
     else
     {
-        uiM.label_snapshotsKeep -> setVisible(TRUE);
-        uiM.spinBox_snapshotsKeep -> setVisible(TRUE);
-        uiM.checkBox_backupContents -> setVisible(TRUE);
-        uiM.checkBox_deleteAfter -> setEnabled (TRUE);
+        uiM.label_snapshotsKeep -> setVisible(true);
+        uiM.spinBox_snapshotsKeep -> setVisible(true);
+        uiM.checkBox_backupContents -> setVisible(true);
+        uiM.checkBox_deleteAfter -> setEnabled (true);
     }
 }
 // Include tab stuff  changed=====================================================================================================
 // Enable/disable the "exclude" tab
 void modifyDialog::disableExcludeTab()
 {
-    bool enableIt = TRUE;
+    bool enableIt = true;
     
     // conditions to disable the exclude tab
     if ( ( (uiM.listWidget_include -> count() > 0) || 
        ((uiM.checkBox_includeFile->isChecked()) && ((uiM.lineEdit_includeFile->text()).size() >0)) ) &&
        (uiM.radioButton_includeOnly -> isChecked()) )
        
-       enableIt = FALSE;
+       enableIt = false;
 
     uiM.toolBox_exclude -> setEnabled (enableIt);
 }
@@ -1260,22 +1272,22 @@ operation *modifyDialog::fillOperationArray()
     {
         if (uiM.checkBox_backupContents -> isChecked())
         {
-            pTask -> SetTypeDirContents    ( TRUE );
-            pTask -> SetTypeDirName        ( FALSE );
-            pTask -> SetTypeSync        ( FALSE );
+            pTask -> SetTypeDirContents    ( true );
+            pTask -> SetTypeDirName        ( false );
+            pTask -> SetTypeSync        ( false );
         }
         else
         {
-            pTask -> SetTypeDirContents    ( FALSE );
-            pTask -> SetTypeDirName        ( TRUE );
-            pTask -> SetTypeSync        ( FALSE );
+            pTask -> SetTypeDirContents    ( false );
+            pTask -> SetTypeDirName        ( true );
+            pTask -> SetTypeSync        ( false );
         }
     }
     if (uiM.comboBox_Type -> currentIndex()==1)
     {
-        pTask -> SetTypeDirContents    ( FALSE );
-        pTask -> SetTypeDirName        ( FALSE );
-        pTask -> SetTypeSync        ( TRUE );
+        pTask -> SetTypeDirContents    ( false );
+        pTask -> SetTypeDirName        ( false );
+        pTask -> SetTypeSync        ( true );
         uiM.spinBox_snapshotsKeep -> setValue (1);    // also set the keep snapshots spinbox to "1" if it is a sync task
     }
     
@@ -1377,7 +1389,7 @@ operation *modifyDialog::fillOperationArray()
         uiM.listWidget_executeBefore -> setCurrentRow(count);
         pTask -> AddExecuteBeforeListItem((uiM.listWidget_executeBefore -> currentItem()) -> text());
         if ((uiM.listWidget_executeBefore -> currentItem()) -> checkState() == Qt::Checked)
-            tempState = TRUE;   else tempState = FALSE;
+            tempState = true;   else tempState = false;
         pTask -> AddExecuteBeforeListItemState(tempState);
         count++;
     }
@@ -1387,7 +1399,7 @@ operation *modifyDialog::fillOperationArray()
         uiM.listWidget_executeAfter -> setCurrentRow(count);
         pTask -> AddExecuteAfterListItem((uiM.listWidget_executeAfter -> currentItem()) -> text());
         if ((uiM.listWidget_executeAfter -> currentItem()) -> checkState() == Qt::Checked)
-            tempState = TRUE;   else tempState = FALSE;
+            tempState = true;   else tempState = false;
         pTask -> AddExecuteAfterListItemState(tempState);
         count++;
     }
@@ -1412,18 +1424,18 @@ void modifyDialog::fillModifyWindow(operation *pTask)
     {
         uiM.comboBox_Type -> setCurrentIndex(0);
         uiM.checkBox_backupContents -> setCheckState(Qt::Checked);
-        uiM.checkBox_deleteAfter -> setEnabled (TRUE);
+        uiM.checkBox_deleteAfter -> setEnabled (true);
     }
     if (pTask -> GetTypeDirName())
     {
         uiM.comboBox_Type -> setCurrentIndex(0);
         uiM.checkBox_backupContents -> setCheckState(Qt::Unchecked);
-        uiM.checkBox_deleteAfter -> setEnabled (TRUE);
+        uiM.checkBox_deleteAfter -> setEnabled (true);
     }
     if (pTask -> GetTypeSync())
     {
         uiM.comboBox_Type -> setCurrentIndex(1);
-        uiM.checkBox_deleteAfter -> setEnabled (FALSE);
+        uiM.checkBox_deleteAfter -> setEnabled (false);
     }
 
     uiM.lineEdit_source             -> setText    (pTask -> GetSource() );
@@ -1503,7 +1515,7 @@ void modifyDialog::fillModifyWindow(operation *pTask)
         uiM.listWidget_executeBefore -> addItem    (pTask -> GetExecuteBeforeListItem(count));
         uiM.listWidget_executeBefore -> setCurrentRow(uiM.listWidget_executeBefore -> count()-1);
         uiM.listWidget_executeBefore -> currentItem() -> setToolTip (alsoExecuteTooltip);
-        if (pTask -> GetExecuteBeforeListItemState(count) == TRUE)
+        if (pTask -> GetExecuteBeforeListItemState(count) == true)
             uiM.listWidget_executeBefore -> currentItem() -> setCheckState(Qt::Checked);
         else
             uiM.listWidget_executeBefore -> currentItem() -> setCheckState(Qt::Unchecked);
@@ -1515,7 +1527,7 @@ void modifyDialog::fillModifyWindow(operation *pTask)
         uiM.listWidget_executeAfter -> addItem    (pTask -> GetExecuteAfterListItem(count));
         uiM.listWidget_executeAfter -> setCurrentRow(uiM.listWidget_executeAfter -> count()-1);
         uiM.listWidget_executeAfter -> currentItem() -> setToolTip (alsoExecuteTooltip);
-        if (pTask -> GetExecuteAfterListItemState(count) == TRUE)
+        if (pTask -> GetExecuteAfterListItemState(count) == true)
             uiM.listWidget_executeAfter -> currentItem() -> setCheckState(Qt::Checked);
         else
             uiM.listWidget_executeAfter -> currentItem() -> setCheckState(Qt::Unchecked);
@@ -1598,10 +1610,10 @@ void modifyDialog::modifyTrailing()
                 destDir.append(SLASH);
         }
         
-        uiM.checkBox_deleteAfter    -> setChecked    (FALSE);
-        uiM.checkBox_update         -> setChecked    (TRUE);
-        uiM.checkBox_ownership      -> setChecked    (TRUE);
-        uiM.checkBox_permissions    -> setChecked    (TRUE);
+        uiM.checkBox_deleteAfter    -> setChecked    (false);
+        uiM.checkBox_update         -> setChecked    (true);
+        uiM.checkBox_ownership      -> setChecked    (true);
+        uiM.checkBox_permissions    -> setChecked    (true);
     }
     
     /*if (WINrunning)     // some more adjustments for windows when the user wants to declare directly paths with "/" instead of "\" (normally for remote)
