@@ -23,7 +23,7 @@
  project version    : Please see "main.cpp" for project version
 
  developer          : luckyb 
- last modified      : 11 Sep 2013
+ last modified      : 22 May 2016
 ===============================================================================================================================
 ===============================================================================================================================
 */
@@ -32,6 +32,7 @@
 #ifndef OPERATIONCLASS_H
 #define OPERATIONCLASS_H
 #include <QDateTime>
+#include <QStringList>
 
 //==============================================================================================================
 //Declaration of operation class (this is the class that holds operation's name & arguments)
@@ -47,22 +48,22 @@ class operation
             itsDestination = "";
             itsConnectRestore = "";
             itsLastExecutionErrors = -1;
-            itsExclude = FALSE;
-            itsInclude = FALSE;
-            itsIncludeModeNormal = FALSE;
-            itsByPassWARNING = FALSE;
-            itsCloneWARNING = TRUE;
+            itsExclude = false;
+            itsInclude = false;
+            itsIncludeModeNormal = false;
+            itsByPassWARNING = false;
+            itsCloneWARNING = true;
             itsRepeatOnFail = 0;
             itsKeepSnapshots = 1;
             itsSnapshotsList.clear();
-            itsOptionsFATntfs = FALSE;
-            itsOptionsSuper = FALSE;
-            itsOptionsNumericIDs = FALSE;
-            itsOptionsVss = FALSE;
-            itsOptionsRestorent = FALSE;
-            itsIncludeFromFile = FALSE;
-            itsExcludeFromFile = FALSE;
-            itsExcludeGVFS = FALSE;
+            itsOptionsFATntfs = false;
+            itsOptionsSuper = false;
+            itsOptionsNumericIDs = false;
+            itsOptionsVss = false;
+            itsOptionsRestorent = false;
+            itsIncludeFromFile = false;
+            itsExcludeFromFile = false;
+            itsExcludeGVFS = false;
             itsExecuteBeforeList.clear();
             itsExecuteBeforeListState.clear();
             itsExecuteAfterList.clear();
@@ -223,8 +224,8 @@ class operation
         void SetExclude()                      { if ( ((itsExcludeFromFile) && !(itsExcludeFile=="")) || (itsExcludeTemp)||(itsExcludeCache)||(itsExcludeBackup)||
                                     (itsExcludeMount)||(itsExcludeLostFound)||(itsExcludeSystem)||
                                     (itsExcludeTrash)||(itsExcludeGVFS)||(itsExcludeList.size()>0) )
-                                        itsExclude = TRUE;
-                                    else     itsExclude = FALSE; }
+                                        itsExclude = true;
+                                    else     itsExclude = false; }
         // Exclude templates
         void SetExcludeTemp(bool ExcludeTemp)               { itsExcludeTemp = ExcludeTemp;}
         void SetExcludeCache (bool ExcludeCache)            { itsExcludeCache = ExcludeCache;}
@@ -244,8 +245,8 @@ class operation
         // Include boolean
         void SetInclude()                      {  if ( ((itsIncludeFromFile) && !(itsIncludeFile=="")) || 
                                             (itsIncludeList.size()>0) )
-                                        itsInclude = TRUE;
-                                    else    itsInclude = FALSE;}
+                                        itsInclude = true;
+                                    else    itsInclude = false;}
         // Include from file
         void SetIncludeFromFile(bool IncludeFromFile)       { itsIncludeFromFile = IncludeFromFile;}
         // Include mode
