@@ -49,9 +49,9 @@ class schedule
             itsWeekDay = 0;
             itsHour = 0;
             itsMinute = 0;
-            itsSkipCritical = TRUE;
-            itsConsoleMode = FALSE;
-            itsReboot = FALSE;
+            itsSkipCritical = true;
+            itsConsoleMode = false;
+            itsReboot = false;
             itsDelayReboot = 3;
         }
         ~schedule() {}								//destructor
