@@ -23,7 +23,7 @@
  project version    : Please see "main.cpp" for project version
 
  developer          : luckyb 
- last modified      : 30 Aug 2010
+ last modified      : 22 May 2016
 
 ===============================================================================================================================
 ===============================================================================================================================
@@ -31,14 +31,18 @@
 
 #include "textDialog.h"
 
+#include <QClipboard>
+
+#include "global.h"
+
 // class textDialog Constructor=================================================================================================
 // Displays a simple dialog with text info, ok-cancel buttons and a lineEdit for user input
 textDialog::textDialog (const QString type, const QString ReplaceInput, QWidget *parent) : QDialog (parent)
 {
 	uiT.setupUi(this);
-	uiT.checkBox_select -> setVisible(FALSE);
-	uiT.label_warning -> setVisible(FALSE);
-	uiT.textEdit_userInput -> setVisible(FALSE);
+	uiT.checkBox_select -> setVisible(false);
+	uiT.label_warning -> setVisible(false);
+	uiT.textEdit_userInput -> setVisible(false);
 	
 	//connect okay & cancel pushButton SLOTs ----------------
 	connect ( uiT.pushButton_ok, SIGNAL( clicked() ), this, SLOT( okay() ) );
@@ -61,8 +65,8 @@ textDialog::textDialog (const QString type, const QString ReplaceInput, QWidget
 	}
 	if (type == "ProfileDescription")
 	{
-		uiT.lineEdit_userInput 	-> setVisible(FALSE);
-		uiT.textEdit_userInput -> setVisible(TRUE);
+		uiT.lineEdit_userInput 	-> setVisible(false);
+		uiT.textEdit_userInput -> setVisible(true);
 		this -> resize(640, 480);
 		uiT.label_message 	-> setText(tr("Profile description :"));
 		uiT.textEdit_userInput 	-> setPlainText(ReplaceInput);
@@ -78,7 +82,7 @@ textDialog::textDialog (const QString type, const QString ReplaceInput, QWidget
 	}
 	if (type == "password")
 	{
-		uiT.label_message 	-> setText(tr("Enter pasword :"));
+		uiT.label_message 	-> setText(tr("Enter password :"));
 		uiT.lineEdit_userInput 	-> setEchoMode (QLineEdit::Password);
 	}
 	if (type == "passphrase")
@@ -88,18 +92,18 @@ textDialog::textDialog (const QString type, const QString ReplaceInput, QWidget
 	}
 	if (type == "CloneWarning")
 	{
-		uiT.checkBox_select -> setVisible(TRUE);
-		uiT.label_warning -> setVisible(TRUE);
+		uiT.checkBox_select -> setVisible(true);
+		uiT.label_warning -> setVisible(true);
 		uiT.checkBox_select -> setText (tr("Do not show this again for this task"));
-		uiT.lineEdit_userInput 	-> setVisible(FALSE);
+		uiT.lineEdit_userInput 	-> setVisible(false);
 		uiT.label_message 	-> setText(tr("You have selected to \"Backup the contents of the source directory\"<br>together with the \"delete files on the destination\" option") +"<br><br>" + tr("BEWARE, if your intention is NOT to clone source to destination !!") +"<br><br>" + 
 				tr("Are you sure you wish to proceed ??") + "<br><br>");
         resize(sizeHint());
 	}
 	if (type == "ValidateDialog")
 	{
-		uiT.lineEdit_userInput 	-> setVisible(FALSE);
-		uiT.label_warning -> setVisible(TRUE);
+		uiT.lineEdit_userInput 	-> setVisible(false);
+		uiT.label_warning -> setVisible(true);
 		uiT.label_warning -> setPixmap(QPixmap(":/luckyPrefix/validate.png"));
 		uiT.pushButton_cancel -> setText(tr("Copy command to clipboard"));
 		uiT.pushButton_cancel -> setIcon(QIcon(":/luckyPrefix/copy.png"));
@@ -109,56 +113,56 @@ textDialog::textDialog (const QString type, const QString ReplaceInput, QWidget
 	if (type == "ViewCurrentCrontab")
 	{
 		this -> resize(640, 480);
-		uiT.lineEdit_userInput 	-> setVisible(FALSE);
-		uiT.pushButton_cancel -> setVisible(FALSE);
+		uiT.lineEdit_userInput 	-> setVisible(false);
+		uiT.pushButton_cancel -> setVisible(false);
 		uiT.label_message 	-> setText(ReplaceInput);
 	}
 	if (type == "emailOutput")
     {
-        uiT.lineEdit_userInput  -> setVisible(FALSE);
-        uiT.textEdit_userInput -> setVisible(TRUE);
+        uiT.lineEdit_userInput  -> setVisible(false);
+        uiT.textEdit_userInput -> setVisible(true);
         this -> resize(640, 480);
         uiT.label_message   -> setText(tr("eMail information"));
         uiT.textEdit_userInput  -> setPlainText(ReplaceInput);
-        uiT.textEdit_userInput  -> setReadOnly(TRUE);
-        uiT.pushButton_cancel   -> setVisible(FALSE);
+        uiT.textEdit_userInput  -> setReadOnly(true);
+        uiT.pushButton_cancel   -> setVisible(false);
     }
 	
 	// The next are used instead of standard Qt dialogs for translation reasons
 	if (type == "QtInformation")
 	{
-		uiT.lineEdit_userInput 	-> setVisible(FALSE);
-		uiT.label_warning 	-> setVisible(TRUE);
+		uiT.lineEdit_userInput 	-> setVisible(false);
+		uiT.label_warning 	-> setVisible(true);
 		uiT.label_warning 	-> setPixmap(QPixmap(":/luckyPrefix/validate.png"));
 		uiT.label_message 	-> setText(ReplaceInput);
 		
-		uiT.pushButton_cancel 	-> setVisible(FALSE);
+		uiT.pushButton_cancel 	-> setVisible(false);
         resize(sizeHint());
 	}
 	if (type == "QtWarning")
 	{
-		uiT.lineEdit_userInput 	-> setVisible(FALSE);
-		uiT.label_warning 	-> setVisible(TRUE);
+		uiT.lineEdit_userInput 	-> setVisible(false);
+		uiT.label_warning 	-> setVisible(true);
 		uiT.label_warning 	-> setPixmap(QPixmap(":/luckyPrefix/warning.png"));
 		uiT.label_message 	-> setText(ReplaceInput);
 		
-		uiT.pushButton_cancel 	-> setVisible(FALSE);
+		uiT.pushButton_cancel 	-> setVisible(false);
         resize(sizeHint());
 	}
 	if (type == "QtCritical")
 	{
-		uiT.lineEdit_userInput 	-> setVisible(FALSE);
-		uiT.label_warning 	-> setVisible(TRUE);
+		uiT.lineEdit_userInput 	-> setVisible(false);
+		uiT.label_warning 	-> setVisible(true);
 		uiT.label_warning 	-> setPixmap(QPixmap(":/luckyPrefix/cancel.png"));
 		uiT.label_message 	-> setText(ReplaceInput);
 		
-		uiT.pushButton_cancel 	-> setVisible(FALSE);
+		uiT.pushButton_cancel 	-> setVisible(false);
         resize(sizeHint());
 	}
 	if (type == "QtQuestion")
 	{
-		uiT.lineEdit_userInput 	-> setVisible(FALSE);
-		uiT.label_warning 	-> setVisible(TRUE);
+		uiT.lineEdit_userInput 	-> setVisible(false);
+		uiT.label_warning 	-> setVisible(true);
 		uiT.label_warning 	-> setPixmap(QPixmap(":/luckyPrefix/about.png"));
 		uiT.label_message 	-> setText(ReplaceInput);
 		
